use Acme::Phlegethoth;
ia ia! NgSlL'HAaGL ulN GRaH'n!  NnnBUg h'kadiShtu!  nGuAaAhAgL ph'NOg VUlgTLAgln GnAIIh!  cFm'LATgh yFhTAGn nAfLLllL cH' NAGnAIih ThrODOr HaFh'dRN!  f'r'luhnYth uh'E 'fHALmAoR roN NaFLorR'E Ch'otH kADIsHTu 'aI!  NNnbug!  ep NgeEoG FM'LatgH KADIshtu mgyAr nG'fhaLMa sTElL'BSna n'GhAagl yhrii NA'FhAlma cHTeNFf zHROoTH!  ooBOShuog HrIinyTh zhRoyaR ehyE Ch' Ph'ilyAAaGL mg NOGaGl nOg 'FHaLManyTH f'mnahn' Ee hAFh'drN Ph''ai oObOShU naflHRii H'R'LuHYar gOtHA Gothaor K'yarnAk HAFh'DrNog N'GhFTotH WGah'n ShUGGnyTh roN nw Ch' lLlL yoOBoSHUagl H'kAdish [Text ends abruptly.]
